@@ -119,7 +119,7 @@ func listAction(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	if len(allinstances) == 0 {
-		logrus.Warn("No instance found. Run `limactl start` to create an instance.")
+		logrus.Warn("No instance found. Run `limactl create` to create an instance.")
 		return nil
 	}
 
@@ -177,6 +177,6 @@ func listAction(cmd *cobra.Command, args []string) error {
 	return store.PrintInstances(out, instances, format, &options)
 }
 
-func listBashComplete(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+func listBashComplete(cmd *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
 	return bashCompleteInstanceNames(cmd)
 }
