@@ -48,6 +48,9 @@ type BootCmds struct {
 type Disk struct {
 	Name   string
 	Device string
+	Format bool
+	FSType string
+	FSArgs []string
 }
 type TemplateArgs struct {
 	Name                            string // instance name
@@ -58,6 +61,7 @@ type TemplateArgs struct {
 	Mounts                          []Mount
 	MountType                       string
 	Disks                           []Disk
+	GuestInstallPrefix              string
 	Containerd                      Containerd
 	Networks                        []Network
 	SlirpNICName                    string
