@@ -8,6 +8,7 @@ import (
 
 type LimaYAML struct {
 	VMType             *VMType         `yaml:"vmType,omitempty" json:"vmType,omitempty"`
+	OS                 *OS             `yaml:"os,omitempty" json:"os,omitempty"`
 	Arch               *Arch           `yaml:"arch,omitempty" json:"arch,omitempty"`
 	Images             []Image         `yaml:"images" json:"images"` // REQUIRED
 	CPUType            map[Arch]string `yaml:"cpuType,omitempty" json:"cpuType,omitempty"`
@@ -39,11 +40,14 @@ type LimaYAML struct {
 	Rosetta           Rosetta        `yaml:"rosetta,omitempty" json:"rosetta,omitempty"`
 }
 
+type OS = string
 type Arch = string
 type MountType = string
 type VMType = string
 
 const (
+	LINUX OS = "Linux"
+
 	X8664   Arch = "x86_64"
 	AARCH64 Arch = "aarch64"
 	ARMV7L  Arch = "armv7l"
