@@ -7,7 +7,6 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
-	"runtime"
 	"sync"
 
 	"github.com/goccy/go-yaml"
@@ -52,6 +51,26 @@ func defaultConfigBytes() ([]byte, error) {
 	return textutil.ExecuteTemplate(defaultConfigTemplate, args)
 }
 
+func fillDefaults(nwYaml YAML) (YAML, error) {
+	usernetFound := false
+	if nwYaml.Networks == nil {
+		nwYaml.Networks = make(map[string]Network)
+	}
+	for nw := range nwYaml.Networks {
+		if nwYaml.Networks[nw].Mode == ModeUserV2 {
+			usernetFound = true
+		}
+	}
+	if !usernetFound {
+		defaultConfig, err := DefaultConfig()
+		if err != nil {
+			return nwYaml, err
+		}
+		nwYaml.Networks[ModeUserV2] = defaultConfig.Networks[ModeUserV2]
+	}
+	return nwYaml, nil
+}
+
 func DefaultConfig() (YAML, error) {
 	var config YAML
 	defaultConfig, err := defaultConfigBytes()
@@ -117,14 +136,15 @@ func loadCache() {
 		if cache.err != nil {
 			cache.err = fmt.Errorf("cannot parse %q: %w", configFile, cache.err)
 		}
+		cache.config, cache.err = fillDefaults(cache.config)
+		if cache.err != nil {
+			cache.err = fmt.Errorf("cannot fill default %q: %w", configFile, cache.err)
+		}
 	})
 }
 
 // Config returns the network config from the _config/networks.yaml file.
 func Config() (YAML, error) {
-	if runtime.GOOS != "darwin" {
-		return YAML{}, errors.New("networks.yaml configuration is only supported on macOS right now")
-	}
 	loadCache()
 	return cache.config, cache.err
 }
@@ -144,6 +164,15 @@ func Sock(name string) (string, error) {
 	return cache.config.Sock(name), nil
 }
 
+// Usernet Returns true if the given network name is usernet network
+func Usernet(name string) (bool, error) {
+	loadCache()
+	if cache.err != nil {
+		return false, cache.err
+	}
+	return cache.config.Usernet(name)
+}
+
 // VDESock returns a vde socket.
 //
 // Deprecated. Use Sock.
