@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"path/filepath"
 
+	"github.com/lima-vm/lima/pkg/osutil"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 )
 
@@ -12,7 +13,7 @@ type SockType = string
 const (
 	FDSock       = "fd"
 	QEMUSock     = "qemu"
-	EndpointSock = "endpoint"
+	EndpointSock = "ep"
 )
 
 // Sock returns a usernet socket based on name and sockType.
@@ -21,12 +22,20 @@ func Sock(name string, sockType SockType) (string, error) {
 	if err != nil {
 		return "", err
 	}
-	return SockWithDirectory(filepath.Join(dir, name), name, sockType), nil
+	return SockWithDirectory(filepath.Join(dir, name), name, sockType)
 }
 
 // SockWithDirectory return a usernet socket based on dir, name and sockType
-func SockWithDirectory(dir string, name string, sockType SockType) string {
-	return filepath.Join(dir, fmt.Sprintf("usernet_%s_%s.sock", name, sockType))
+func SockWithDirectory(dir string, name string, sockType SockType) (string, error) {
+	if name == "" {
+		name = "default"
+	}
+	sockPath := filepath.Join(dir, fmt.Sprintf("%s_%s.sock", name, sockType))
+	if len(sockPath) >= osutil.UnixPathMax {
+		return "", fmt.Errorf("usernet socket path %q too long: must be less than UNIX_PATH_MAX=%d characters, but is %d",
+			sockPath, osutil.UnixPathMax, len(sockPath))
+	}
+	return sockPath, nil
 }
 
 // PIDFile returns a path for usernet PID file
